@@ -7,7 +7,6 @@
 
 // FIXME This implementation won't work on an EBCDIC machine.
 
-#include <strstream.h>
 #include "splib.h"
 #ifdef WINSOCK
 #include <winsock.h>
@@ -19,6 +18,7 @@
 #define SP_HAVE_SOCKET
 #else
 #ifdef SP_HAVE_SOCKET
+#include <stdio.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netdb.h>
@@ -553,14 +553,14 @@ HTTP_RESPONSE_TYPE HttpSocketStorageObject::open(const String<char> &host,
   if (!isdigit((unsigned char)host[0])) {
     request += host;
     if (port != 80) {
+      char portstr[sizeof(unsigned short)*3 + 1];
+      sprintf(portstr, "%u", port);
       request.append(":", 1);
-      ostrstream pbuf ;
-      pbuf << port << ends ;
-      request.append(pbuf.str(), strlen(pbuf.str())) ;
+      request.append(portstr, strlen(portstr));
     } 
   }
   request.append("\r\n", 2);
-  request.append("User-Agent: lq-sp/1.3.4.7\r\n", 27) ;
+  request.append("User-Agent: lq-sp/1.3.4.9\r\n", 27) ;
   request.append("\r\n", 2);
 
   // FIXME check length of write
